# frozen_string_literal: true

# The code was auto-generated by {this script}[https://github.com/cucumber/messages/blob/main/codegen/codegen.rb]
module Cucumber
  module Messages
    class HookType
      BEFORE_TEST_RUN = 'BEFORE_TEST_RUN'
      AFTER_TEST_RUN = 'AFTER_TEST_RUN'
      BEFORE_TEST_CASE = 'BEFORE_TEST_CASE'
      AFTER_TEST_CASE = 'AFTER_TEST_CASE'
      BEFORE_TEST_STEP = 'BEFORE_TEST_STEP'
      AFTER_TEST_STEP = 'AFTER_TEST_STEP'
    end
  end
end
