# frozen_string_literal: true

# The code was auto-generated by {this script}[https://github.com/cucumber/messages/blob/main/codegen/codegen.rb]
module Cucumber
  module Messages
    class TestStepResultStatus
      UNKNOWN = 'UNKNOWN'
      PASSED = 'PASSED'
      SKIPPED = 'SKIPPED'
      PENDING = 'PENDING'
      UNDEFINED = 'UNDEFINED'
      AMBIGUOUS = 'AMBIGUOUS'
      FAILED = 'FAILED'
    end
  end
end
