# frozen_string_literal: true

# The code was auto-generated by {this script}[https://github.com/cucumber/messages/blob/main/codegen/codegen.rb]
module Cucumber
  module Messages
    class AttachmentContentEncoding
      IDENTITY = 'IDENTITY'
      BASE64 = 'BASE64'
    end
  end
end
