# frozen_string_literal: true

# The code was auto-generated by {this script}[https://github.com/cucumber/messages/blob/main/codegen/codegen.rb]
module Cucumber
  module Messages
    class StepKeywordType
      UNKNOWN = 'Unknown'
      CONTEXT = 'Context'
      ACTION = 'Action'
      OUTCOME = 'Outcome'
      CONJUNCTION = 'Conjunction'
    end
  end
end
