# frozen_string_literal: true

# The code was auto-generated by {this script}[https://github.com/cucumber/messages/blob/main/codegen/codegen.rb]
module Cucumber
  module Messages
    class StepDefinitionPatternType
      CUCUMBER_EXPRESSION = 'CUCUMBER_EXPRESSION'
      REGULAR_EXPRESSION = 'REGULAR_EXPRESSION'
    end
  end
end
